.. _spkg_nlohmann_json:

nlohmann_json: JSON for modern C++
==================================

Description
-----------

JSON library


License
-------

MIT


Upstream Contact
----------------

https://github.com/nlohmann/json


Type
----

optional


Dependencies
------------

- :ref:`spkg_cmake`
- :ref:`spkg_ninja_build`

Version Information
-------------------

package-version.txt::

    3.12.0

Equivalent System Packages
--------------------------

(none known)
